package de.jeyp91.apifootball;

import org.junit.Test;

import java.io.IOException;

public class APIFootballUpdaterTest {

    @Test
    public void updateFixturesTest() throws IOException {
        APIFootballUpdater updater = new APIFootballUpdater(2021);
        // updater.updateFixtures(2743);
    }

    @Test
    public void updateAllFixturesTest() throws IOException {
        APIFootballUpdater updater = new APIFootballUpdater(2021);
        // updater.updateAllFixtures("Tippliga.json");
        // updater.updateAllFixtures("WTL_Pokal.json");
    }

    @Test
    public void updateAllRoundsTest() throws IOException {
        APIFootballUpdater updater = new APIFootballUpdater(2021);
        // updater.updateAllRounds("Tippliga.json");
        // updater.updateAllRounds("WTL_Pokal.json");
    }
}
